/*
 * 🌟 Santa's Sleigh Safety Script 🌟
 * Author: Polarion’s Head Elf
 *
 * This script ensures Santa's magical sleigh route is clear of cosmic objects.
 * Merry Christmas from the Polarion Team! 🎄🎅
 */

const HttpRequest = Java.type('java.net.http.HttpRequest'); 
const URI = Java.type('java.net.URI'); 
const Duration = Java.type('java.time.Duration'); 

const httpClient = context.scriptContext().utils().httpClient(); 

const SANTA_API_KEY = 'DEMO_KEY'; 
const today = new Date().toISOString().split('T')[0]; 
const SANTA_SLEIGH_PATH_CHECK_URL = new URI(`https://api.nasa.gov/neo/rest/v1/feed?start_date=${today}&end_date=${today}&api_key=${SANTA_API_KEY}`);
const REINDEER_REQUEST_TIMEOUT = Duration.ofSeconds(5); 

var request = HttpRequest.newBuilder() 
    .uri(SANTA_SLEIGH_PATH_CHECK_URL) 
    .header("Content-Type", "application/json") 
    .timeout(REINDEER_REQUEST_TIMEOUT) 
    .GET() 
    .build(); 

console.log("🎄 Checking Santa's flight path for cosmic obstacles...");
try { 
    var result = httpClient.sendRequest(request); 

    if (result.statusCode() === 200) { 
        const responseBody = JSON.parse(result.body()); 
        const neoData = responseBody.near_earth_objects[today]; 

        if (neoData && neoData.length > 0) { 
            console.log(`🚨 Multiple objects detected: ${neoData.length} Frosty Fragments in Santa's path!`);
            const firstObject = neoData[0]; 
            const objectName = firstObject.name; 
            const objectDistance = parseFloat(firstObject.close_approach_data[0].miss_distance.kilometers); 

            if (objectDistance < 10000) { 
                throw new PolarionScriptingException(`🎅 Alert! Object ${objectName} detected at ${objectDistance} km. Santa's sleigh is grounded!`);
            } else { 
                console.log(`🎄 All clear! Object ${objectName} is at a safe distance of ${objectDistance} kilometers.`);
            } 
        } else { 
            console.log("🎅 Hooray! No near-Earth objects threatening Santa's route today.");
        } 
    } else { 
        throw new PolarionScriptingException("🎁 NASA API request failed. Santa’s route verification blocked.");
    } 
} catch (error) { 
    throw new PolarionScriptingException("❄️ Oops! NASA's API is down. Manual sky checks required!");
}
console.log("🦌 Reindeer ready. ✨ All systems go for Santa's sleigh ride!");
